.. bluepy3 documentation master file, created by
   sphinx-quickstart on Fri Sep  5 10:07:35 2014.


``bluepy3`` - a Bluetooth LE interface for Python
================================================

``bluepy3`` is a Python module which allows communication with Bluetooth Low
Energy devices. The current implementation runs on Linux
(internally it uses code from the `BlueZ project <http://www.bluez.org/>`_), although it can be ported to other
platforms.

To browse the API documentation, it is recommended to start with :ref:`peripheral`.

Contents:

.. toctree::
   :maxdepth: 2

   peripheral
   scanner
   scanentry
   delegate
   uuid
   service
   characteristic
   descriptor
   notifications
   assignednumbers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
